muon_parse

Function muon_parse 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn muon_parse( ptr: *const u8, len: usize, ) -> *mut u8
Parse len UTF-8 bytes at ptr; return a length-prefixed JSON result.

Safety

ptr/len must describe a valid, initialized block of linear memory (e.g. one from muon_alloc that JS has filled). The returned block is owned by the caller and must be released with muon_free.